#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
console.time('require');
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const commander_1 = require("commander");
const typescript_1 = __importStar(require("typescript"));
const chrome_remote_interface_1 = __importDefault(require("chrome-remote-interface"));
const package_json_1 = __importDefault(require("./package.json"));
console.timeEnd('require');
commander_1.program
    .version(package_json_1.default.version)
    .name('node-remote-repl')
    .usage('[options] <file>')
    .option('-h, --host <string>', 'host of inspect protocol', 'localhost')
    .option('-p, --port <number>', 'port of inspect protocol', Number, 9229)
    .parse(process.argv);
const file = commander_1.program.args[0];
if (!file) {
    console.error('Need to pass <file> argument');
    process.exit(1);
}
const fileExtension = file.match(/(\.js|\.jsx|\.ts|\.tsx)$/)?.[1];
if (!fileExtension) {
    console.error('Support only js or ts file extensions');
    process.exit(1);
}
const filePath = path_1.default.resolve(process.cwd(), file);
if (!fs_1.default.existsSync(filePath)) {
    console.error(`File on path: "${filePath}" not exists`);
    process.exit(1);
}
const fileContent = fs_1.default.readFileSync(filePath, { encoding: 'utf8' });
const expression = fileExtension === '.js'
    ? fileContent
    : typescript_1.default.transpileModule(fileContent, {
        compilerOptions: {
            lib: ['es2020'],
            module: typescript_1.ModuleKind.CommonJS,
            target: typescript_1.ScriptTarget.ES2020,
            esModuleInterop: true,
            jsx: fileExtension.endsWith('x') ? typescript_1.default.JsxEmit.React : void 0,
        },
    }).outputText;
(async () => {
    const client = await (0, chrome_remote_interface_1.default)({
        host: commander_1.program.opts().host,
        port: commander_1.program.opts().port,
    });
    const resp = await client.Runtime.evaluate({
        expression: `(async () => {
      const exports = {};
      ${expression}
      if (exports.$replJson) {
        return JSON.stringify(await exports.$replJson(), null, 2);
      }
      if (exports.$repl) {
        return await exports.$repl();
      }
    })()`,
        includeCommandLineAPI: true,
        awaitPromise: true,
    });
    console.log(resp.result.value || resp);
    client.close();
})().catch((e) => {
    console.error(e);
    process.exit(1);
});
